pub fn main()
Entry point for the program. Reads cli and env args, sets up logging, initializes the Database, and starts up the Actix HTTP server and inbox delivery loop (activitypub::inbox_queue). The HTTP server serves requests using the responders in http_api (most of the API) and frontend (see the files in the “frontend” folder at the root of the repository for the specific files served).